==> haskell-posix-paths-0.3.0.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-posix-paths.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 posix-paths
version:              0.3.0.0
visibility:           public
id:                   posix-paths-0.3.0.0-3HBGJcFg0h3LOli0ZViE0S
key:                  posix-paths-0.3.0.0-3HBGJcFg0h3LOli0ZViE0S
license:              BSD-3-Clause
maintainer:           jwlato@gmail.com
synopsis:             POSIX filepath/directory functionality
description:
    This package gives access to certain POSIX-based Filepath/Directory
    services.

    The package is not supported under Windows (except under Cygwin).

category:             System
abi:                  8475e662c6647277e0adcb1ebd59e070
exposed:              True
exposed-modules:
    System.Posix.Directory.Foreign System.Posix.Directory.Traversals
    System.Posix.FilePath

import-dirs:          /usr/lib/ghc-9.2.8/site-local/posix-paths-0.3.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/posix-paths-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-posix-paths
hs-libraries:         HSposix-paths-0.3.0.0-3HBGJcFg0h3LOli0ZViE0S
depends:
    base-4.16.4.0 bytestring-0.11.4.0 unix-2.7.2.2
    unliftio-0.2.25.0-GFYnbt2k2E3HdB4VAzWEMx

haddock-interfaces:   /usr/share/doc/haskell-posix-paths/html/posix-paths.haddock
haddock-html:         /usr/share/doc/haskell-posix-paths/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-posix-paths-0.3.0.0-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-posix-paths.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 posix-paths
version:              0.3.0.0
visibility:           public
id:                   posix-paths-0.3.0.0-JPl3FxBfQ9tP9XdEJzFht
key:                  posix-paths-0.3.0.0-JPl3FxBfQ9tP9XdEJzFht
license:              BSD-3-Clause
maintainer:           jwlato@gmail.com
synopsis:             POSIX filepath/directory functionality
description:
    This package gives access to certain POSIX-based Filepath/Directory
    services.

    The package is not supported under Windows (except under Cygwin).

category:             System
abi:                  446a9e37636f9be39fd49923c0b6bb41
exposed:              True
exposed-modules:
    System.Posix.Directory.Foreign System.Posix.Directory.Traversals
    System.Posix.FilePath

import-dirs:          /usr/lib/ghc-9.2.8/site-local/posix-paths-0.3.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/posix-paths-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-posix-paths
hs-libraries:         HSposix-paths-0.3.0.0-JPl3FxBfQ9tP9XdEJzFht
depends:
    base-4.16.4.0 bytestring-0.11.4.0 unix-2.7.2.2
    unliftio-0.2.25.0-GCGuYURqqybKqtlFVsyJQb

haddock-interfaces:   /usr/share/doc/haskell-posix-paths/html/posix-paths.haddock
haddock-html:         /usr/share/doc/haskell-posix-paths/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
